import java_cup.runtime.*;

/**
 * Lexer for the NumericRange parameter of a ReadValueId.
 */
%%

%class NRLexer
%unicode
%cup
%line
%column

%{
  // StringBuffer string = new StringBuffer();

  private Symbol symbol(int type) {
    return new Symbol(type, yyline, yycolumn);
  }
  private Symbol symbol(int type, Object value) {
    return new Symbol(type, yyline, yycolumn, value);
  }
%}

LineTerminator 	= \r|\n|\r\n
WhiteSpace     	= {LineTerminator} | [ \t\f]
Digit			= [0-9]

%%

<YYINITIAL> {
  {Digit}                   	{ return symbol( sym.DIGIT, new Integer(yytext()) ); }

  ":"                           { return symbol(sym.COLON); }
  ","                           { return symbol(sym.COMMA); }

  {WhiteSpace}                  { /* ignore */ }
}

/* error fallback */
.|\n                            { throw new Error("Illegal character <" + yytext() + ">"); }

